# **Welcome to Optumi 👋**

### Description

Optumi is a cloud service that makes it easy for data scientists to develop & train ML models on powerful computing resources.

We offer a Python API library, a web application and a JupyterLab extension to launch and manage python scripts and notebooks in the cloud. We offer access to a wide variety of powerful cloud resources used for interactive sessions or batch jobs.
